==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebPinColumnCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDetailDescription } from "./WebPinColumnCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPinColumnCancellableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, _super);
    function WebPinColumnCancellableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a == null) {
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.j(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.y(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b(a);
        a.aa("WebPinColumnCancellableEventArgsDetail", function () { return new WebPinColumnCancellableEventArgsDetailDescription(); });
        a.z("WebPinColumnCancellableEventArgsDetail", WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.$t = markType(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, 'WebPinColumnCancellableEventArgsDetailDescriptionMetadata');
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPinColumnCancellableEventArgsDetailDescriptionMetadata };

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm5/lib/WebPinColumnCancellableEventArgsDetailDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCancelableEventArgsDetailDescriptionMetadata } from "./WebCancelableEventArgsDetailDescriptionMetadata";
import { WebPinColumnCancellableEventArgsDetailDescription } from "./WebPinColumnCancellableEventArgsDetailDescription";
/**
 * @hidden
 */
var WebPinColumnCancellableEventArgsDetailDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, _super);
    function WebPinColumnCancellableEventArgsDetailDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b = function (a) {
        if (WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a == null) {
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
        }
        if (a.k(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.c = function (a) {
        WebCancelableEventArgsDetailDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:PinColumnCancellableEventArgsDetail");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.d = function (a) {
        WebPinColumnCancellableEventArgsDetailDescriptionMetadata.b(a);
        a.ac("WebPinColumnCancellableEventArgsDetail", function () { return new WebPinColumnCancellableEventArgsDetailDescription(); });
        a.ab("WebPinColumnCancellableEventArgsDetail", WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a);
    };
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.$t = markType(WebPinColumnCancellableEventArgsDetailDescriptionMetadata, 'WebPinColumnCancellableEventArgsDetailDescriptionMetadata');
    WebPinColumnCancellableEventArgsDetailDescriptionMetadata.a = null;
    return WebPinColumnCancellableEventArgsDetailDescriptionMetadata;
}(Base));
export { WebPinColumnCancellableEventArgsDetailDescriptionMetadata };
